@@ -1,5 +1,5 @@
 package App::CharmKit::Role::Init;
-$App::CharmKit::Role::Init::VERSION = '0.006';
+$App::CharmKit::Role::Init::VERSION = '0.007';
 # ABSTRACT: Initialization of new charms
 
 use YAML::Tiny;
@@ -42,7 +42,7 @@ perltidy.LOG
     $path->child('.gitignore')->spew_utf8($gitignore);
 
     # tests/tests.yaml
-    my $yaml = YAML::Tiny->new({packages => ['perl']});
+    my $yaml = YAML::Tiny->new({packages => ['perl', 'make']});
     $yaml->write($path->child('tests/tests.yaml'));
 
     # src/tests/00-basic.test
@@ -51,8 +51,7 @@ perltidy.LOG
 
 use charm -tester;
 
-# How to write test using Test::More
-use_ok('App::CharmKit');
+# Start tests
 done_testing;
 }
     );
@@ -126,7 +125,14 @@ HOOKS_DIR := $(PWD)/hooks
 TEST_DIR := $(PWD)/tests
 
 ensure_ck:
-	@apt-get -qyf install cpanminus
+	@apt-get -qyf install cpanminus \
+		libnet-ssleay-perl \
+		libio-socket-ssl-perl \
+		libio-prompter-perl \
+		libapp-fatpacker-perl \
+		libipc-system-simple-perl \
+		libsoftware-license-perl \
+		libautodie-perl
 	@cpanm App::CharmKit --notest
 
 pack:
@@ -161,7 +167,7 @@ App::CharmKit::Role::Init - Initialization of new charms
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 METHODS
 
